@@ -1,9 +1,7 @@
 
 /*
- *  Time-stamp:        "2011-05-15 11:10:06 bkorb"
- *
  *  This file is part of Complexity.
- *  Complexity Copyright (c) 2011 by Bruce Korb - all rights reserved
+ *  Complexity Copyright (c) 2011-2014 by Bruce Korb - all rights reserved
  *
  *  Complexity is free software: you can redistribute it and/or modify it
  *  under the terms of the GNU General Public License as published by the
@@ -22,7 +20,7 @@
 #ifndef COMPLEXITY_H_GUARD
 #define COMPLEXITY_H_GUARD
 
-#define _GNU_SOURCE 1
+#include "config.h"
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -30,17 +28,11 @@
 #include <ctype.h>
 #include <errno.h>
 #include <stdarg.h>
-#include <stdio.h>
-#include <stdlib.h>
 #include <string.h>
-#include <unistd.h>
 
 #include "char-types.h"
-
 #include "opts.h"
 
-typedef enum { false = 0, true = 1 } bool_t;
-
 #ifndef NUL
 # define NUL '\0'
 #endif
@@ -103,7 +95,7 @@ typedef struct {
     char const *    fname;
     char const *    text;
     char const *    scan;
-    bool_t          bol;
+    bool            bol;
     token_t         last_tkn;
     char const *    tkn_text;
     size_t          tkn_len;
@@ -146,7 +138,7 @@ next_token(fstate_t * fs);
 extern void
 unget_token(fstate_t * fs);
 
-extern bool_t
+extern bool
 find_proc_start(fstate_t * fs);
 
 extern void
